%define upstream_name    UNIVERSAL-can
%define upstream_version 1.20140328

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 10

Summary:    Hack around calling UNIVERSAL::can() as a function
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/UNIVERSAL/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker) >= 6.300.0
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::More)
BuildRequires: perl(lib)
BuildRequires: perl(overload)
BuildRequires: perl(strict)
BuildRequires: perl(vars)
BuildRequires: perl(warnings)
BuildRequires: perl(warnings::register)
BuildArch:  noarch

%{?perl_default_filter}

%description
The UNIVERSAL class provides a few default methods so that all objects can use
them. Object orientation allows programmers to override these methods in
subclasses to provide more specific and appropriate behavior.

Some authors call methods in the UNIVERSAL class on potential invocants as
functions, bypassing any possible overriding. This is wrong and you should not
do it. Unfortunately, not everyone heeds this warning and their bad code can
break your good code.

Fortunately, this upstream_name replaces UNIVERSAL::can() with a method that checks to
see if the first argument is a valid invocant (whether an object -- a blessed
referent -- or the name of a class). If so, and if the invocant's class has its
own can() method, it calls that as a method. Otherwise, everything works as you
might expect.

If someone attempts to call UNIVERSAL::can() as a function, this upstream_name will
emit a lexical warning (see perllexwarn) to that effect. You can disable it
with no warnings; or no warnings 'UNIVERSAL::isa';, but don't do that; fix the
code instead.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
%make_build test

%install
%make_install

%files 
%doc Changes LICENSE META.yml MYMETA.yml README
%{perl_vendorlib}/UNIVERSAL
%{_mandir}/*/*


%changelog
* Sun Mar 20 2022 umeabot <umeabot> 1.201.403.280-10.mga9
+ Revision: 1806545
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 1.201.403.280-9.mga8
+ Revision: 1497959
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 1.201.403.280-8.mga7
+ Revision: 1272409
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 1.201.403.280-7.mga6
+ Revision: 1035522
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 1.201.403.280-6.mga6
+ Revision: 949716
- Mageia 6 Mass Rebuild

* Sun Oct 19 2014 umeabot <umeabot> 1.201.403.280-5.mga5
+ Revision: 790335
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.201.403.280-4.mga5
+ Revision: 749096
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 1.201.403.280-3.mga5
+ Revision: 732591
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 1.201.403.280-2.mga5
+ Revision: 686758
- Mageia 5 Mass Rebuild

* Tue Apr 15 2014 jquelin <jquelin> 1.201.403.280-1.mga5
+ Revision: 615025
- update to 1.20140328

* Mon Feb 10 2014 jquelin <jquelin> 1.201.401.240-1.mga5
+ Revision: 588809
- update to 1.20140124

* Fri Oct 18 2013 umeabot <umeabot> 1.201.207.260-3.mga4
+ Revision: 515777
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.201.207.260-2.mga3
+ Revision: 374513
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 31 2012 kharec <kharec> 1.201.207.260-1.mga3
+ Revision: 286568
- update to 1.20120726

* Tue Jun 21 2011 jquelin <jquelin> 1.201.106.170-1.mga2
+ Revision: 111459
- update to 1.20110617

* Fri Jun 17 2011 jquelin <jquelin> 1.201.106.140-1.mga2
+ Revision: 109024
- update to 1.20110614

* Fri Jan 21 2011 jquelin <jquelin> 1.160.0-1.mga1
+ Revision: 29231
- mageia rebuild
- imported package perl-UNIVERSAL-can


* Fri Jan 15 2010 Jérôme Quelin <jquelin@mandriva.org> 1.160.0-1mdv2010.1
+ Revision: 491635
- update to 1.16

* Thu Jan 14 2010 Jérôme Quelin <jquelin@mandriva.org> 1.150.0-2mdv2010.1
+ Revision: 491286
- fix upstream bug #49580 - deep recursion on string overloading

* Tue Jul 07 2009 Jérôme Quelin <jquelin@mandriva.org> 1.150.0-1mdv2010.0
+ Revision: 393108
- update to 1.15
- fix license field

* Sun Jun 21 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.140.0-1mdv2010.0
+ Revision: 387864
- new version

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 1.12-6mdv2009.0
+ Revision: 242108
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Sep 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.12-4mdv2008.0
+ Revision: 87065
- rebuild


* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.12-3mdv2007.0
- Rebuild

* Fri Apr 28 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.12-2mdk
- Fix SPEC according to Perl Policy
    - BuildRequires
    - Source URL

* Sat Apr 01 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.12-1mdk
- New release 1.12

* Wed Mar 01 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.11-1mdk
- New release 1.11

* Mon Jan 16 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-1mdk
- New release 1.03

* Tue Dec 20 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.01-2mdk
- Add BuildRequires

* Thu Dec 15 2005 Guillaume Rousse <guillomovitch@mandriva.org> 1.01-1mdk
- New release 1.01

* Mon Oct 03 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.00-2mdk
- Fix BuildRequires

* Tue Sep 20 2005 Guillaume Rousse <guillomovitch@mandriva.org> 1.00-1mdk
- first mdk release

